pub enum IdentityPropertyFormatKind {
FunctionCall(IdentityParameters),
StartAndIncrement(IdentityParameters),
}Expand description
A format of parameters of identity column.
It is Snowflake specific. Syntax
(seed , increment) | START num INCREMENT numMS SQL Server uses one way of representing these parameters. Syntax
(seed , increment)Variants
FunctionCall(IdentityParameters)
A parameters of identity column declared like parameters of function call Example:
(100, 1)StartAndIncrement(IdentityParameters)
A parameters of identity column declared with keywords START and INCREMENT
Example:
START 100 INCREMENT 1Trait Implementations
Sourceimpl AsNodeKey for IdentityPropertyFormatKind
impl AsNodeKey for IdentityPropertyFormatKind
fn as_node_key(&self) -> NodeKey<'_>
Sourceimpl Clone for IdentityPropertyFormatKind
impl Clone for IdentityPropertyFormatKind
Sourcefn clone(&self) -> IdentityPropertyFormatKind
fn clone(&self) -> IdentityPropertyFormatKind
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdentityPropertyFormatKind
impl Debug for IdentityPropertyFormatKind
Sourceimpl Display for IdentityPropertyFormatKind
impl Display for IdentityPropertyFormatKind
Sourceimpl Hash for IdentityPropertyFormatKind
impl Hash for IdentityPropertyFormatKind
Sourceimpl Ord for IdentityPropertyFormatKind
impl Ord for IdentityPropertyFormatKind
Sourcefn cmp(&self, other: &IdentityPropertyFormatKind) -> Ordering
fn cmp(&self, other: &IdentityPropertyFormatKind) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for IdentityPropertyFormatKind
impl PartialOrd for IdentityPropertyFormatKind
Sourceimpl<'ast> Transformable<'ast> for IdentityPropertyFormatKind
impl<'ast> Transformable<'ast> for IdentityPropertyFormatKind
Sourceimpl Visitable for IdentityPropertyFormatKind
impl Visitable for IdentityPropertyFormatKind
Sourcefn accept<'ast, V: Visitor<'ast>>(
&'ast self,
visitor: &mut V,
) -> ControlFlow<Break<V::Error>>
fn accept<'ast, V: Visitor<'ast>>( &'ast self, visitor: &mut V, ) -> ControlFlow<Break<V::Error>>
Accepts a borrowed
Visitor and traverses the AST starting at self invoking Visitor::enter and
Visitor::exit as nodes are entered and exiting respectively.Sourcefn downcast_ref<Target: Visitable>(&self) -> Option<&Target>
fn downcast_ref<Target: Visitable>(&self) -> Option<&Target>
Tries to downcast
self as &Target.Sourcefn downcast_mut<Target: Visitable>(&mut self) -> Option<&mut Target>
fn downcast_mut<Target: Visitable>(&mut self) -> Option<&mut Target>
Tries to downcast
self as &mut Target.impl Eq for IdentityPropertyFormatKind
impl StructuralPartialEq for IdentityPropertyFormatKind