JoinOperator

Enum JoinOperator 

pub enum JoinOperator {
Show 18 variants Join(JoinConstraint), Inner(JoinConstraint), Left(JoinConstraint), LeftOuter(JoinConstraint), Right(JoinConstraint), RightOuter(JoinConstraint), FullOuter(JoinConstraint), CrossJoin, Semi(JoinConstraint), LeftSemi(JoinConstraint), RightSemi(JoinConstraint), Anti(JoinConstraint), LeftAnti(JoinConstraint), RightAnti(JoinConstraint), CrossApply, OuterApply, AsOf { match_condition: Expr, constraint: JoinConstraint, }, StraightJoin(JoinConstraint),
}

Variants



Join(JoinConstraint)



Inner(JoinConstraint)



Left(JoinConstraint)



LeftOuter(JoinConstraint)



Right(JoinConstraint)



RightOuter(JoinConstraint)



FullOuter(JoinConstraint)



CrossJoin



Semi(JoinConstraint)

SEMI (non-standard)



LeftSemi(JoinConstraint)

LEFT SEMI (non-standard)



RightSemi(JoinConstraint)

RIGHT SEMI (non-standard)



Anti(JoinConstraint)

ANTI (non-standard)



LeftAnti(JoinConstraint)

LEFT ANTI (non-standard)



RightAnti(JoinConstraint)

RIGHT ANTI (non-standard)



CrossApply

CROSS APPLY (non-standard)



OuterApply

OUTER APPLY (non-standard)



AsOf

ASOF joins are used for joining tables containing time-series data whose timestamp columns do not match exactly.

See https://docs.snowflake.com/en/sql-reference/constructs/asof-join.

Fields

match_condition: Expr
constraint: JoinConstraint


StraightJoin(JoinConstraint)

STRAIGHT_JOIN (non-standard)

See https://dev.mysql.com/doc/refman/8.4/en/join.html.