TriggerObject

Enum TriggerObject 

pub enum TriggerObject {
    Row,
    Statement,
}
This specifies whether the trigger function should be fired once for every row affected by the trigger event, or just once per SQL statement.

Variants



Row



Statement