pub struct ColumnOptionDef {
pub name: Option<Ident>,
pub option: ColumnOption,
}Expand description
An optionally-named ColumnOption: [ CONSTRAINT <name> ] <column-option>.
Note that implementations are substantially more permissive than the ANSI
specification on what order column options can be presented in, and whether
they are allowed to be named. The specification distinguishes between
constraints (NOT NULL, UNIQUE, PRIMARY KEY, and CHECK), which can be named
and can appear in any order, and other options (DEFAULT, GENERATED), which
cannot be named and must appear in a fixed order. PostgreSQL, however,
allows preceding any option with CONSTRAINT <name>, even those that are
not really constraints, like NULL and DEFAULT. MSSQL is less permissive,
allowing DEFAULT, UNIQUE, PRIMARY KEY and CHECK to be named, but not NULL or
NOT NULL constraints (the last of which is in violation of the spec).
For maximum flexibility, we don’t distinguish between constraint and non-constraint options, lumping them all together under the umbrella of “column options,” and we allow any column option to be named.
Fields
name: Option<Ident>option: ColumnOptionTrait Implementations
Sourceimpl AsNodeKey for ColumnOptionDef
impl AsNodeKey for ColumnOptionDef
fn as_node_key(&self) -> NodeKey<'_>
Sourceimpl Clone for ColumnOptionDef
impl Clone for ColumnOptionDef
Sourcefn clone(&self) -> ColumnOptionDef
fn clone(&self) -> ColumnOptionDef
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ColumnOptionDef
impl Debug for ColumnOptionDef
Sourceimpl Display for ColumnOptionDef
impl Display for ColumnOptionDef
Sourceimpl Hash for ColumnOptionDef
impl Hash for ColumnOptionDef
Sourceimpl Ord for ColumnOptionDef
impl Ord for ColumnOptionDef
Sourcefn cmp(&self, other: &ColumnOptionDef) -> Ordering
fn cmp(&self, other: &ColumnOptionDef) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for ColumnOptionDef
impl PartialEq for ColumnOptionDef
Sourceimpl PartialOrd for ColumnOptionDef
impl PartialOrd for ColumnOptionDef
Sourceimpl Spanned for ColumnOptionDef
impl Spanned for ColumnOptionDef
Sourceimpl<'ast> Transformable<'ast> for ColumnOptionDef
impl<'ast> Transformable<'ast> for ColumnOptionDef
Sourceimpl Visitable for ColumnOptionDef
impl Visitable for ColumnOptionDef
Sourcefn accept<'ast, V: Visitor<'ast>>(
&'ast self,
visitor: &mut V,
) -> ControlFlow<Break<V::Error>>
fn accept<'ast, V: Visitor<'ast>>( &'ast self, visitor: &mut V, ) -> ControlFlow<Break<V::Error>>
Visitor and traverses the AST starting at self invoking Visitor::enter and
Visitor::exit as nodes are entered and exiting respectively.Sourcefn downcast_ref<Target: Visitable>(&self) -> Option<&Target>
fn downcast_ref<Target: Visitable>(&self) -> Option<&Target>
self as &Target.Sourcefn downcast_mut<Target: Visitable>(&mut self) -> Option<&mut Target>
fn downcast_mut<Target: Visitable>(&mut self) -> Option<&mut Target>
self as &mut Target.