pub struct Declare {
pub names: Vec<Ident>,
pub data_type: Option<DataType>,
pub assignment: Option<DeclareAssignment>,
pub declare_type: Option<DeclareType>,
pub binary: Option<bool>,
pub sensitive: Option<bool>,
pub scroll: Option<bool>,
pub hold: Option<bool>,
pub for_query: Option<Box<Query>>,
}Expand description
A DECLARE statement.
PostgreSQL Snowflake BigQuery
Examples:
DECLARE variable_name := 42
DECLARE liahona CURSOR FOR SELECT * FROM films;Fields
names: Vec<Ident>The name(s) being declared. Example: `DECLARE a, b, c DEFAULT 42;
data_type: Option<DataType>Data-type assigned to the declared variable. Example: `DECLARE x INT64 DEFAULT 42;
assignment: Option<DeclareAssignment>Expression being assigned to the declared variable.
declare_type: Option<DeclareType>Represents the type of the declared variable.
binary: Option<bool>Causes the cursor to return data in binary rather than in text format.
sensitive: Option<bool>None = Not specified Some(true) = INSENSITIVE Some(false) = ASENSITIVE
scroll: Option<bool>None = Not specified Some(true) = SCROLL Some(false) = NO SCROLL
hold: Option<bool>None = Not specified Some(true) = WITH HOLD, specifies that the cursor can continue to be used after the transaction that created it successfully commits Some(false) = WITHOUT HOLD, specifies that the cursor cannot be used outside of the transaction that created it
for_query: Option<Box<Query>>FOR <query> clause in a CURSOR declaration.