pub struct Function {
pub name: ObjectName,
pub uses_odbc_syntax: bool,
pub parameters: FunctionArguments,
pub args: FunctionArguments,
pub filter: Option<Box<Expr>>,
pub null_treatment: Option<NullTreatment>,
pub over: Option<WindowType>,
pub within_group: Vec<OrderByExpr>,
}Expand description
A function call
Fields
name: ObjectNameuses_odbc_syntax: boolparameters: FunctionArgumentsThe parameters to the function, including any options specified within the delimiting parentheses.
Example:
HISTOGRAM(0.5, 0.6)(x, y)args: FunctionArgumentsThe arguments to the function, including any options specified within the delimiting parentheses.
filter: Option<Box<Expr>>e.g. x > 5 in COUNT(x) FILTER (WHERE x > 5)
null_treatment: Option<NullTreatment>Indicates how NULLs should be handled in the calculation.
Example:
FIRST_VALUE( <expr> ) [ { IGNORE | RESPECT } NULLS ] OVER ...over: Option<WindowType>The OVER clause, indicating a window function call.
within_group: Vec<OrderByExpr>A clause used with certain aggregate functions to control the ordering within grouped sets before the function is applied.
Syntax:
<aggregate_function>(expression) WITHIN GROUP (ORDER BY key [ASC | DESC], ...)Trait Implementations
Sourceimpl Ord for Function
impl Ord for Function
Sourceimpl PartialOrd for Function
impl PartialOrd for Function
Sourceimpl<'ast> Transformable<'ast> for Function
impl<'ast> Transformable<'ast> for Function
Sourceimpl Visitable for Function
impl Visitable for Function
Sourcefn accept<'ast, V: Visitor<'ast>>(
&'ast self,
visitor: &mut V,
) -> ControlFlow<Break<V::Error>>
fn accept<'ast, V: Visitor<'ast>>( &'ast self, visitor: &mut V, ) -> ControlFlow<Break<V::Error>>
Accepts a borrowed
Visitor and traverses the AST starting at self invoking Visitor::enter and
Visitor::exit as nodes are entered and exiting respectively.Sourcefn downcast_ref<Target: Visitable>(&self) -> Option<&Target>
fn downcast_ref<Target: Visitable>(&self) -> Option<&Target>
Tries to downcast
self as &Target.Sourcefn downcast_mut<Target: Visitable>(&mut self) -> Option<&mut Target>
fn downcast_mut<Target: Visitable>(&mut self) -> Option<&mut Target>
Tries to downcast
self as &mut Target.impl Eq for Function
impl StructuralPartialEq for Function