pub enum TriggerObject {
Row,
Statement,
}Expand description
This specifies whether the trigger function should be fired once for every row affected by the trigger event, or just once per SQL statement.
Variants